smart_edge_alert library
Classes
- OverlayView
- OverlayView class manages the creation and dismissal of the overlay alert.
- SmartAnimatedIcon
- SmartAnimatedIcon class represents the animated icon displayed in the overlay alert.
- SmartEdgeAlert
- SmartEdgeAlert class provides functionality to display an interrupted smart alert from the top or bottom of the screen.
- SmartEdgeOverlay
- SmartEdgeOverlay class represents the visual appearance of the overlay alert.
- SmartOverlayWidget
- SmartOverlayWidget class represents the content of the overlay alert.